==> kubernetes-model-networking-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/networking/v1/IngressStatusBuilder.java <==
package io.fabric8.kubernetes.api.model.networking.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class IngressStatusBuilder extends IngressStatusFluentImpl<IngressStatusBuilder> implements VisitableBuilder<IngressStatus,IngressStatusBuilder>{
  public IngressStatusBuilder() {
    this(false);
  }
  public IngressStatusBuilder(Boolean validationEnabled) {
    this(new IngressStatus(), validationEnabled);
  }
  public IngressStatusBuilder(IngressStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public IngressStatusBuilder(IngressStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new IngressStatus(), validationEnabled);
  }
  public IngressStatusBuilder(IngressStatusFluent<?> fluent,IngressStatus instance) {
    this(fluent, instance, false);
  }
  public IngressStatusBuilder(IngressStatusFluent<?> fluent,IngressStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withLoadBalancer(instance.getLoadBalancer());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public IngressStatusBuilder(IngressStatus instance) {
    this(instance,false);
  }
  public IngressStatusBuilder(IngressStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withLoadBalancer(instance.getLoadBalancer());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  IngressStatusFluent<?> fluent;
  Boolean validationEnabled;
  public IngressStatus build() {
    IngressStatus buildable = new IngressStatus(fluent.getLoadBalancer());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> kubernetes-model-networking-6.8.1-sources.jar: io/fabric8/kubernetes/api/model/networking/v1/IngressStatusBuilder.java <==
package io.fabric8.kubernetes.api.model.networking.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class IngressStatusBuilder extends IngressStatusFluent<IngressStatusBuilder> implements VisitableBuilder<IngressStatus,IngressStatusBuilder>{
  public IngressStatusBuilder() {
    this(false);
  }
  public IngressStatusBuilder(Boolean validationEnabled) {
    this(new IngressStatus(), validationEnabled);
  }
  public IngressStatusBuilder(IngressStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public IngressStatusBuilder(IngressStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new IngressStatus(), validationEnabled);
  }
  public IngressStatusBuilder(IngressStatusFluent<?> fluent,IngressStatus instance) {
    this(fluent, instance, false);
  }
  public IngressStatusBuilder(IngressStatusFluent<?> fluent,IngressStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new IngressStatus());

    if (instance != null) {
      fluent.withLoadBalancer(instance.getLoadBalancer());
      fluent.withLoadBalancer(instance.getLoadBalancer());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public IngressStatusBuilder(IngressStatus instance) {
    this(instance,false);
  }
  public IngressStatusBuilder(IngressStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new IngressStatus());

    if (instance != null) {
      this.withLoadBalancer(instance.getLoadBalancer());
      this.withLoadBalancer(instance.getLoadBalancer());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  IngressStatusFluent<?> fluent;
  Boolean validationEnabled;
  public IngressStatus build() {
    IngressStatus buildable = new IngressStatus(fluent.buildLoadBalancer());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
